#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-checked
version:              0.3
visibility:           public
id:                   data-checked-0.3-7qMQqU9Ljdk3KKWXzaseHH
key:                  data-checked-0.3-7qMQqU9Ljdk3KKWXzaseHH
license:              BSD-3-Clause
copyright:            2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/data-checked
synopsis:             Type-indexed runtime-checked properties 
description:
    This package provides a (phantom) type-indexed newtype evidence-wrapper for
    values that are checked to satisfy the property associated with the type.

category:             Data
abi:                  383b466b92ec211627243a01c1dedfa6
exposed:              True
exposed-modules:      Data.Checked Data.Checked.Strict
import-dirs:          /usr/lib/ghc-8.10.5/site-local/data-checked-0.3
library-dirs:         /usr/lib/ghc-8.10.5/site-local/data-checked-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/data-checked-0.3
hs-libraries:         HSdata-checked-0.3-7qMQqU9Ljdk3KKWXzaseHH
depends:              base-4.14.2.0 deepseq-1.4.4.0
haddock-interfaces:
    /usr/share/doc/haskell-data-checked/html/data-checked.haddock

haddock-html:         /usr/share/doc/haskell-data-checked/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

